@@ -148,7 +148,8 @@ def add_parser(subparsers, _parent_parser):
     pull_parser.set_defaults(func=CmdDataPull)
 
     # Push
-    PUSH_HELP = "Push data files to a DVC remote storage."
+    PUSH_HELP = "Uploads files or directories tracked by DVC"
+    " to remote storage."
 
     push_parser = subparsers.add_parser(
         "push",
@@ -191,7 +192,8 @@ def add_parser(subparsers, _parent_parser):
     push_parser.set_defaults(func=CmdDataPush)
 
     # Fetch
-    FETCH_HELP = "Fetch data files from a DVC remote storage."
+    FETCH_HELP = "Get files or directories tracked by DVC from remote storage"
+    " into the cache."
 
     fetch_parser = subparsers.add_parser(
         "fetch",
